==> moodle-1.4.3-pgsql.tgz: moodle/lang/ja/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004121600)


$string['addresource'] = '꥽ɲä';
$string['chooseafile'] = 'եޤϥåץ';
$string['chooseparameter'] = 'ѥ᡼';
$string['configdefaulturl'] = 'ǤϿURL١Υ꥽äϤͤꤷޤ';
$string['configfilterexternalpages'] = 'ˤƤγ꥽ ( ֥ڡåץɤHTMLե ) ˸ꤵƤե륿  ( 㤨Ѹ콸ư ) ŬѤޤꤹ뤳Ȥǥڡư٤ʤ붲줬ޤɬפΤդƤȤ';
$string['configframesize'] = 'ե졼˥֥ڡ䥢åץɤե뤬ɽΥȥåץե졼 ( ʥӥޤ )Υ ( ԥ ) Ǥ';
$string['configparametersettings'] = 'Ǥϡ꥽Ͽݤ˥եɽǥեȤΥѥ᡼ͤꤷޤǽ˥꥽Ͽ塢ͤϸġΥ桼ΥǥեȤȤʤޤ';
$string['configpopup'] = 'ݥåץåץɥɽ뿷꥽ɲä硢ǥեȤǤΥץѤޤ?';
$string['configpopupdirectories'] = 'ǥեȤǥ쥯ȥ󥯤ݥåץåץɥɽޤ?';
$string['configpopupheight'] = 'ݥåץåץɥΥǥեȤι⤵?';
$string['configpopuplocation'] = 'ݥåץåץɥ˥ǥեȤǥɥ쥹Сɽޤ?';
$string['configpopupmenubar'] = 'ݥåץåץɥ˥ǥեȤǥ˥塼Сɽޤ?';
$string['configpopupresizable'] = 'ݥåץåץɥǥեȤǥꥵޤ?';
$string['configpopupscrollbars'] = 'ݥåץåץɥǥեȤǥ뤵ޤ?';
$string['configpopupstatus'] = 'ݥåץåץɥ˥ǥեȤǥơСɽޤ?';
$string['configpopuptoolbar'] = 'ݥåץåץɥ˥ǥեȤǥġСɽޤ?';
$string['configpopupwidth'] = 'ݥåץåץɥΥǥեȤ?';
$string['configsecretphrase'] = 'Υåȥɤϡ꥽ѥ᡼Ȥ˻ѤŹ楳ɤ뤿˻ѤޤŹ楳ɤϡ桼IPɥ쥹ȥåȥɤӤĤmd5ˤޤˤꡢ꥽٤˥ƥкȤ줿̿¸뤳ȤǤޤ';
$string['configwebsearch'] = 'URL򥦥֥ڡޤϥ󥯤ȤɲäΥϡ桼URL򸡺뤿ΥإפȤ󶡤ޤ';
$string['configwindowsettings'] = 'Ǥϡ꥽Ͽݤ˥եɽ륦ɥ˴ؤͤϿޤǽ˥꥽Ͽ塢ͤϸġΥ桼ΥǥեȤȤʤޤ';
$string['directlink'] = 'Υե쥯ȥ󥯤';
$string['directoryinfo'] = '򤷤ǥ쥯ȥե뤬ɽޤ';
$string['display'] = 'ɥ';
$string['editingaresource'] = '꥽Խ';
$string['encryptedcode'] = 'Ź沽';
$string['example'] = '';
$string['exampleurl'] = 'http://www.example.com/somedirectory/somefile.html';
$string['fetchclienterror'] = '֥ڡ򸡺Ƥ֥饤Ȥ˥顼ȯޤURLְäƤȻפޤ';
$string['fetcherror'] = '֥ڡ򸡺Ƥ顼ȯޤ';
$string['fetchservererror'] = '֥ڡ򸡺Ƥ⡼ȥФ˥顼ȯޤץ२顼Ȼפޤ';
$string['filename'] = 'ե̾';
$string['filtername'] = '꥽ȥ';
$string['frameifpossible'] = 'ʥӥɽޤޤˤ뤿ᡢ꥽ե졼ɽ';
$string['fulltext'] = 'եƥ';
$string['htmlfragment'] = 'HTMLե饰';
$string['maindirectory'] = 'ᥤեǥ쥯ȥ';
$string['modulename'] = '꥽';
$string['modulenameplural'] = '꥽';
$string['neverseen'] = '̤ǧ';
$string['newdirectories'] = 'ǥ쥯ȥ󥯤ɽ';
$string['newfullscreen'] = 'ɽ';
$string['newheight'] = 'ǥեȥɥ ( ԥ )';
$string['newlocation'] = 'Сɽ';
$string['newmenubar'] = '˥塼Сɽ';
$string['newresizable'] = 'ɥΥꥵ';
$string['newscrollbars'] = 'ɥΥ';
$string['newstatus'] = 'ơСɽ';
$string['newtoolbar'] = 'ġСɽ';
$string['newwidth'] = 'ǥեȥɥ ( ԥ )';
$string['newwindow'] = 'ɥ';
$string['newwindowopen'] = 'ݥåץåץɥ˥꥽ɽ';
$string['note'] = '';
$string['notefile'] = '˥ե򥢥åץ ( ΥꥹȤɽޤ ) 硢<a href=$a >File Manager</a> ѤƤ';
$string['notypechosen'] = 'פ򤷤Ƥץܥ򲡤ƺϤƤ';
$string['pagedisplay'] = '꥽򸽺ߤΥɥɽ';
$string['pagewindow'] = 'Ʊ쥦ɥ';
$string['parameter'] = 'ѥ᡼';
$string['parameters'] = 'ѥ᡼';
$string['popupresource'] = '꥽ݥåץåץɥɽ';
$string['popupresourcelink'] = 'ɥɽʤϤ򥯥å $a';
$string['resourcetype'] = '꥽Υ';
$string['resourcetype1'] = '';
$string['resourcetype2'] = '֥ڡ';
$string['resourcetype3'] = 'åץɥե';
$string['resourcetype4'] = 'ץ쥤ƥ';
$string['resourcetype5'] = '֥';
$string['resourcetype6'] = 'HTMLƥ';
$string['resourcetype7'] = 'ץ';
$string['resourcetype8'] = 'Wiki-likeƥ';
$string['resourcetype9'] = 'ǥ쥯ȥ';
$string['resourcetypedirectory'] = 'ǥ쥯ȥɽ';
$string['resourcetypefile'] = 'ե롦֥Ȥ˥';
$string['resourcetypehtml'] = '֥ڡκ';
$string['resourcetypelabel'] = '٥';
$string['resourcetypetext'] = 'ƥȥڡκ';
$string['searchweb'] = '֥ڡ򸡺';
$string['variablename'] = 'ѿ̾';

?>

==> moodle-1.5-pgsql.tgz: moodle/lang/ja/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005041101)


$string['addresource'] = '꥽ɲä';
$string['chooseafile'] = 'եޤϥåץ';
$string['chooseparameter'] = 'ѥ᡼';
$string['configallowlocalfiles'] = '꥽ˡCDɥ饤֤ϡɥǥΤ褦ʥե륷ƥؤΥ󥯤ĤޤϡƤγ̤Υͥåȥɥ饤֤CD¸Ƥե˥ȤǤεǽѤˤϡ֥饦Υƥѹɬפʾ⤢ޤ';
$string['configdefaulturl'] = 'ǤϿURL١Υ꥽äϤͤꤷޤ';
$string['configfilterexternalpages'] = 'ˤƤγ꥽ ( ֥ڡåץɤHTMLե ) ˸ꤵƤե륿  ( 㤨Ѹ콸ư ) ŬѤޤꤹ뤳Ȥǥڡư٤ʤ붲줬ޤɬפΤդƤȤ';
$string['configframesize'] = 'ե졼˥֥ڡ䥢åץɤե뤬ɽΥȥåץե졼 ( ʥӥޤ )Υ ( ԥ ) Ǥ';
$string['configparametersettings'] = 'Ǥϡ꥽Ͽݤ˥եɽǥեȤΥѥ᡼ͤꤷޤǽ˥꥽Ͽ塢ͤϸġΥ桼ΥǥեȤȤʤޤ';
$string['configpopup'] = 'ݥåץåץɥɽ뿷꥽ɲä硢ǥեȤǤΥץѤޤ?';
$string['configpopupdirectories'] = 'ǥեȤǥ쥯ȥ󥯤ݥåץåץɥɽޤ?';
$string['configpopupheight'] = 'ݥåץåץɥΥǥեȤι⤵?';
$string['configpopuplocation'] = 'ݥåץåץɥ˥ǥեȤǥɥ쥹Сɽޤ?';
$string['configpopupmenubar'] = 'ݥåץåץɥ˥ǥեȤǥ˥塼Сɽޤ?';
$string['configpopupresizable'] = 'ݥåץåץɥǥեȤǥꥵޤ?';
$string['configpopupscrollbars'] = 'ݥåץåץɥǥեȤǥ뤵ޤ?';
$string['configpopupstatus'] = 'ݥåץåץɥ˥ǥեȤǥơСɽޤ?';
$string['configpopuptoolbar'] = 'ݥåץåץɥ˥ǥեȤǥġСɽޤ?';
$string['configpopupwidth'] = 'ݥåץåץɥΥǥեȤ?';
$string['configsecretphrase'] = 'Υåȥɤϡ꥽ѥ᡼Ȥ˻ѤŹ楳ɤ뤿˻ѤޤŹ楳ɤϡ桼IPɥ쥹ȥåȥɤӤĤmd5ˤޤˤꡢ꥽٤˥ƥкȤ줿̿¸뤳ȤǤޤ';
$string['configwebsearch'] = 'URL򥦥֥ڡޤϥ󥯤ȤɲäΥϡ桼URL򸡺뤿ΥإפȤ󶡤ޤ';
$string['configwindowsettings'] = 'Ǥϡ꥽Ͽݤ˥եɽ륦ɥ˴ؤͤϿޤǽ˥꥽Ͽ塢ͤϸġΥ桼ΥǥեȤȤʤޤ';
$string['directlink'] = 'Υե쥯ȥ󥯤';
$string['directoryinfo'] = '򤷤ǥ쥯ȥե뤬ɽޤ';
$string['display'] = 'ɥ';
$string['editingaresource'] = '꥽Խ';
$string['encryptedcode'] = 'Ź沽';
$string['example'] = '';
$string['exampleurl'] = 'http://www.example.com/somedirectory/somefile.html';
$string['fetchclienterror'] = '֥ڡ򸡺Ƥ֥饤Ȥ˥顼ȯޤURLְäƤȻפޤ';
$string['fetcherror'] = '֥ڡ򸡺Ƥ顼ȯޤ';
$string['fetchservererror'] = '֥ڡ򸡺Ƥ⡼ȥФ˥顼ȯޤץ२顼Ȼפޤ';
$string['filename'] = 'ե̾';
$string['filtername'] = '꥽ȥ';
$string['frameifpossible'] = 'ʥӥɽޤޤˤ뤿ᡢ꥽ե졼ɽ';
$string['fulltext'] = 'ܺ';
$string['htmlfragment'] = 'HTMLե饰';
$string['localfile'] = 'ե';
$string['localfilechoose'] = 'ե (CD-ROM)';
$string['localfilehelp'] = 'եɽ˴ؤإ';
$string['localfileinfo'] = 'p>ʤΥԥ塼ե򤷤Ƥ եϥ֥Ȥ˥åץɤޤ󤬡MoodleϤΥ꥽Ʊե̾Υե򥳥ԥ塼夫õޤ</p><p>ϡƤλüԤˡCD-ROM¸Ƥ̥ǥۤ˺ǤǤ줾λüԤϡΤ褦ʥեΤˡ<a href=\"$a\" target=\"_blank\">桼ץեԽ</a>뤳ȤǡȼΥѥ򤹤뤳ȤǤޤ.</p> 	';
$string['localfilepath'] = 'Υ꥽ȼΥѥꤹˤϡ꥽¸ߤ뤢ʤΥԥ塼Υɥ饤 ( ̾CD_ROM ) ե򤷤Ƥեϥåץɤޤ󤬡ɥ饤־¸ޤξϥ꥽λȤ˻Ѥޤ';
$string['localfileselect'] = 'Υեѥ';
$string['maindirectory'] = 'ᥤեǥ쥯ȥ';
$string['modulename'] = '꥽';
$string['modulenameplural'] = '꥽';
$string['neverseen'] = '̤ǧ';
$string['newdirectories'] = 'ǥ쥯ȥ󥯤ɽ';
$string['newfullscreen'] = 'ɽ';
$string['newheight'] = 'ǥեȥɥ ( ԥ )';
$string['newlocation'] = 'Сɽ';
$string['newmenubar'] = '˥塼Сɽ';
$string['newresizable'] = 'ɥΥꥵ';
$string['newscrollbars'] = 'ɥΥ';
$string['newstatus'] = 'ơСɽ';
$string['newtoolbar'] = 'ġСɽ';
$string['newwidth'] = 'ǥեȥɥ ( ԥ )';
$string['newwindow'] = 'ɥ';
$string['newwindowopen'] = 'ݥåץåץɥ˥꥽ɽ';
$string['notallowedlocalfileaccess'] = 'ߡեؤΥߤƤޤΥ꥽ѤǤޤ';
$string['note'] = '';
$string['notefile'] = '˥ե򥢥åץ ( ΥꥹȤɽޤ ) 硢<a href=$a >File Manager</a> ѤƤ';
$string['notypechosen'] = 'פ򤷤Ƥץܥ򲡤ƺϤƤ';
$string['pagedisplay'] = '꥽򸽺ߤΥɥɽ';
$string['pagewindow'] = 'Ʊ쥦ɥ';
$string['pan'] = 'Pan';
$string['parameter'] = 'ѥ᡼';
$string['parameters'] = 'ѥ᡼';
$string['popupresource'] = '꥽ݥåץåץɥɽ';
$string['popupresourcelink'] = 'ɥɽʤϤ򥯥å $a';
$string['resourcetype'] = '꥽Υ';
$string['resourcetype1'] = '';
$string['resourcetype2'] = '֥ڡ';
$string['resourcetype3'] = 'åץɥե';
$string['resourcetype4'] = 'ץ쥤ƥ';
$string['resourcetype5'] = '֥';
$string['resourcetype6'] = 'HTMLƥ';
$string['resourcetype7'] = 'ץ';
$string['resourcetype8'] = 'Wiki-likeƥ';
$string['resourcetype9'] = 'ǥ쥯ȥ';
$string['resourcetypedirectory'] = 'ǥ쥯ȥɽ';
$string['resourcetypefile'] = 'ե롦Ȥ˥';
$string['resourcetypehtml'] = '֥ڡκ';
$string['resourcetypelabel'] = '٥';
$string['resourcetypetext'] = 'ƥȥڡκ';
$string['searchweb'] = '֥ڡ򸡺';
$string['serverurl'] = '$CFG->wwwroot';
$string['variablename'] = 'ѿ̾';
$string['vol'] = 'Vol';

?>
